@@ -7,6 +7,7 @@ import sys
 import tempfile
 import unittest
 
+from django import forms
 from django.contrib.auth.models import Group, User
 from django.db.models import Q
 from django.db.models.query_utils import DeferredAttribute
@@ -21,7 +22,7 @@ try:
 except ImportError:
     mock_signal_receiver = None
 
-
+from mptt.admin import JS
 from mptt.exceptions import CantDisableUpdates, InvalidMove
 from mptt.forms import (
     MPTTAdminForm, TreeNodeChoiceField, TreeNodeMultipleChoiceField,
@@ -1945,3 +1946,108 @@ class DeferredAttributeTests(TreeTestCase):
             obj.save()
 
         self.assertEqual(obj._mptt_cached_fields['name'], 'b')
+
+
+class DraggableMPTTAdminTestCase(TreeTestCase):
+    def setUp(self):
+        self.user = User.objects.create_superuser(
+            'admin', 'test@example.com', 'p')
+        self.client.login(username=self.user.username, password='p')
+
+    def test_changelist(self):
+        p1 = Person.objects.create(name='Franz')
+        p2 = Person.objects.create(name='Fritz')
+        p3 = Person.objects.create(name='Hans')
+
+        self.assertNotEqual(p1._mpttfield('tree_id'), p2._mpttfield('tree_id'))
+
+        response = self.client.get('/admin/myapp/person/')
+        self.assertContains(response, 'class="drag-handle"', 3)
+        self.assertContains(response, 'style="text-indent:0px"', 3)
+        self.assertContains(
+            response,
+            'javascript" src="/static/mptt/draggable-admin.js"'
+            ' data-context="{&quot;')
+        self.assertContains(
+            response,
+            '}" id="draggable-admin-context"></script>')
+
+        response = self.client.post(
+            '/admin/myapp/person/',
+            {
+                'cmd': 'move_node',
+                'cut_item': p1.pk,
+                'pasted_on': p2.pk,
+                'position': 'last-child',
+            },
+            HTTP_X_REQUESTED_WITH='XMLHttpRequest',
+        )
+        self.assertEqual(response.status_code, 200)
+
+        p1.refresh_from_db()
+        p2.refresh_from_db()
+
+        self.assertEqual(p1.parent, p2)
+
+        self.assertTreeEqual(Person.objects.all(), """
+            2 - 2 0 1 4
+            1 2 2 1 2 3
+            3 - 3 0 1 2
+            """)
+
+        response = self.client.get('/admin/myapp/person/')
+        self.assertContains(response, 'style="text-indent:0px"', 2)
+        self.assertContains(response, 'style="text-indent:20px"', 1)
+
+        response = self.client.post(
+            '/admin/myapp/person/',
+            {
+                'cmd': 'move_node',
+                'cut_item': p3.pk,
+                'pasted_on': p1.pk,
+                'position': 'left',
+            },
+            HTTP_X_REQUESTED_WITH='XMLHttpRequest',
+        )
+        self.assertEqual(response.status_code, 200)
+
+        self.assertTreeEqual(Person.objects.all(), """
+            2 - 2 0 1 6
+            3 2 2 1 2 3
+            1 2 2 1 4 5
+            """)
+
+        response = self.client.post('/admin/myapp/person/', {
+            'action': 'delete_selected',
+            '_selected_action': [1],
+        })
+        self.assertContains(response, 'Are you sure?')
+        response = self.client.post('/admin/myapp/person/', {
+            'action': 'delete_selected',
+            '_selected_action': [1],
+            'post': 'yes',
+        })
+
+        self.assertRedirects(response, '/admin/myapp/person/')
+
+        self.assertTreeEqual(Person.objects.all(), """
+            2 - 2 0 1 4
+            3 2 2 1 2 3
+            """)
+
+    def test_js(self):
+        media = forms.Media()
+        media.add_js([
+            JS('asset1.js', {}),
+            JS('asset2.js', {'id': 'something', 'answer': '"42"'}),
+        ])
+
+        # We can test the exact representation since forms.Media has been
+        # really stable for a long time, and JS() uses flatatt which
+        # alphabetically sorts its attributes.
+        self.assertEqual(
+            '%s' % media,
+            '<script type="text/javascript" src="/static/asset1.js"></script>\n'
+            '<script type="text/javascript" src="/static/asset2.js"'
+            ' answer="&quot;42&quot;" id="something"></script>'
+        )
